==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkBorderWidget.java <==
// java wrapper for vtkBorderWidget object
//

package vtk;
import vtk.*;

public class vtkBorderWidget extends vtkAbstractWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSelectable_2(int id0);
  public void SetSelectable(int id0)
    { SetSelectable_2(id0); }

  private native int GetSelectable_3();
  public int GetSelectable()
    { return GetSelectable_3(); }

  private native void SelectableOn_4();
  public void SelectableOn()
    { SelectableOn_4(); }

  private native void SelectableOff_5();
  public void SelectableOff()
    { SelectableOff_5(); }

  private native void SetResizable_6(int id0);
  public void SetResizable(int id0)
    { SetResizable_6(id0); }

  private native int GetResizable_7();
  public int GetResizable()
    { return GetResizable_7(); }

  private native void ResizableOn_8();
  public void ResizableOn()
    { ResizableOn_8(); }

  private native void ResizableOff_9();
  public void ResizableOff()
    { ResizableOff_9(); }

  private native void SetRepresentation_10(vtkBorderRepresentation id0);
  public void SetRepresentation(vtkBorderRepresentation id0)
    { SetRepresentation_10(id0); }

  private native long GetBorderRepresentation_11();
  public vtkBorderRepresentation GetBorderRepresentation() {
    long temp = GetBorderRepresentation_11();

    if (temp == 0) return null;
    return (vtkBorderRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultRepresentation_12();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_12(); }

  public vtkBorderWidget() { super(); }

  public vtkBorderWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkBorderWidget.java <==
// java wrapper for vtkBorderWidget object
//

package vtk;
import vtk.*;

public class vtkBorderWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSelectable_2(int id0);
  public void SetSelectable(int id0)
    { SetSelectable_2(id0); }

  private native int GetSelectable_3();
  public int GetSelectable()
    { return GetSelectable_3(); }

  private native void SelectableOn_4();
  public void SelectableOn()
    { SelectableOn_4(); }

  private native void SelectableOff_5();
  public void SelectableOff()
    { SelectableOff_5(); }

  private native void SetResizable_6(int id0);
  public void SetResizable(int id0)
    { SetResizable_6(id0); }

  private native int GetResizable_7();
  public int GetResizable()
    { return GetResizable_7(); }

  private native void ResizableOn_8();
  public void ResizableOn()
    { ResizableOn_8(); }

  private native void ResizableOff_9();
  public void ResizableOff()
    { ResizableOff_9(); }

  private native void SetRepresentation_10(vtkBorderRepresentation id0);
  public void SetRepresentation(vtkBorderRepresentation id0)
    { SetRepresentation_10(id0); }

  private native long GetBorderRepresentation_11();
  public vtkBorderRepresentation GetBorderRepresentation() {
    long temp = GetBorderRepresentation_11();

    if (temp == 0) return null;
    return (vtkBorderRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_12();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_12(); }

  public vtkBorderWidget() { super(); }

  public vtkBorderWidget(long id) { super(id); }
  public native long   VTKInit();

}
